package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````I18``#0```"D`0$```0`!30`(``*
M`"@`'``;``$``'#<>P``W'L``-Q[```(````"`````0````$````!@```#0`
M```T````-````$`!``!``0``!`````0````#````F`$``)@!``"8`0``&0``
M`!D````$`````0````$```````````````````#T?```]'P```4```````$`
M`0```+S]``"\_0$`O/T!`(P"``"@`@``!@```````0`"````Q/T``,3]`0#$
M_0$`"`$```@!```&````!`````0```!T`0``=`$``'0!```D````)`````0`
M```$````!````.A[``#H>P``Z'L```P!```,`0``!`````0```!1Y71D````
M```````````````````````&````$````%+E=&2\_0``O/T!`+S]`0!$`@``
M1`(```0````!````!````!0````#````1TY5`#*=ME@08ZJ"+??8=#>T"424
M*J](+VQI8B]L9"UL:6YU>"UA<FUH9BYS;RXS`````!$```!+````"`````@`
M```!D!`$)4`$@"B```6@AE"$@($``@LH!(PX@!)!B@``"$L```!,````3P``
M`%,```!4````70```%X```!?`````````&$```!B````8P```&0```!E````
M:````````````````:\TZ&[%WQ_.WD<M:W^:?"[%F[;49-1\=E0\E"'_Y`[9
M<5@<XD?&`;(!BV^L2^/`0OK7A\+E/RQ8[Y=YNN.2?/JA;&"93\.;:PE#UF>O
MS&9"1=7LB0=PTS-BV^T5C"7,#3J7"W^IG)O@IP(*:AJ>4+_:5QNCX/M)````
M``````````````````````#8$0````````,`"@`````````"```````#`!<`
M"0(`````````````$@```.0``````````````!(```#Z`@`````````````2
M````Q0(`````````````$@```+<"`````````````!(```"6````````````
M```2````70$`````````````$@```/H``````````````!(````!````````
M```````@````L`(`````````````$@```"4"`````````````!(````K`0``
M```````````2````&P$`````````````$@```+X"`````````````!(````-
M`0`````````````2````U`$`````````````$@```!```````````````"``
M``![`0`````````````2````S0(`````````````$@```.D`````````````
M`!(```#W`0`````````````2````U`(`````````````$@```"P`````````
M`````"````#\`0`````````````2````1@``````````````$@```&,`````
M`````````!8```!-`0`````````````2````=@``````````````$@```-,`
M`````````````!(```"'```````````````2````Z@$`````````````$@``
M`-P!`````````````!(```#;`@`````````````2````Y`,`````````````
M$@```+<``````````````!(````*`P`````````````1````S0$`````````
M````$@```"0#`````````````!$````/`@`````````````2````/P$`````
M````````$@```,0!`````````````!(```"#`@`````````````2````O0$`
M````````````$@```.X``````````````!(```"K`0`````````````2````
M=`$`````````````$@```)4!`````````````!(```!C`@`````````````2
M````XP$`````````````$@```/$!`````````````!(````2`P``````````
M```2````H@``````````````$@```!X"`````````````!(```!H`0``````
M```````2````-@(`````````````$@````@#`````````````!$```"3`@``
M```````````1````Q@``````````````$0```+,!`````````````!(```"&
M`0`````````````1````1P(`````````````$@`````#`````````````!(`
M```T`0`````````````2````50(`````````````$@```#\"````````````
M`!(```!4```````````````2````<0(`````````````$@```)H"````````
M`````!(```#B`@`````````````2````I@$`````````````$@```.D"````
M`````````!(```"A`@`````````````B````/P0``%P``@``````$``8`.T#
M``#9+```P````!(`#`!D!```#28``/@$```2``P`?@(``-D4``#,`0``$@`,
M`&0#```9'0``!````!(`#`""`P``!2L``-0!```2``P`%00``$@``@``````
M$``8`(H$```='0``H`$``!(`#`!*!```2``"```````0`!@`=0,``+T>```8
M````$@`,`)@#``!](P``8````!(`#`#Y`P``Y#D```0````1``X`(P0``#$X
M``#>````$@`,`"X$```Q'```/````!(`#``V!```7``"```````0`!@`7P0`
M`%P``@``````$``8`'@$``!1)0``O````!(`#`"A!```W2,``$@````2``P`
M"`0``````@``````$``7`+P#``#5'@``#`$``!(`#`!Q!```2``"```````0
M`!<`EP0``$0``@`$````$0`7``X$``"E%@```````!(`#`!6!```O3<``'0`
M```2``P`"@0``````@``````(``7`-(#``!!)0``$````!(`#`"F`P``;1P`
M`*P````2``P`R`,``!$Y``"\````$@`,`#X$``!<``(``````!``&`"I!```
MX1\``)P#```2``P``%]?9VUO;E]S=&%R=%]?`%])5$U?9&5R96=I<W1E<E1-
M0VQO;F5486)L90!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES
M7W1E<FT`4&5R;%]S>7-?:6YI=#,`4$Q?8W5R<F5N=%]C;VYT97AT`%!E<FQ?
M871F;W)K7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C
M<F]A:U]N;V-O;G1E>'0`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E
M<FQ?;F5W6%-?9FQA9W,`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F
M;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L
M7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`8F]O=%]$>6YA3&]A9&5R
M`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?
M;65M;W)Y7W=R87``7U]S=&%C:U]C:&M?9F%I;`!E>&ET`&QS965K-C0`<F5A
M9&1I<C8T`'-T<F1U<`!C;&]S961I<@!O<&5N-C0`<W1R<F-H<@!U;FQI;FL`
M<W1R=&]K`'-T<FQE;@!R;61I<@!R96%D`%]?;65M8W!Y7V-H:P!M:V1I<@!?
M7W9F<')I;G1F7V-H:P!G971P:60`7U]L<W1A=#8T7W1I;64V-`!R96%D;&EN
M:P!R96%L;&]C`%]?<W!R:6YT9E]C:&L`7U]M96UM;W9E7V-H:P!?7V9P<FEN
M=&9?8VAK`%]?;&EB8U]S=&%R=%]M86EN`%]?<W1A=#8T7W1I;64V-`!S=&1E
M<G(`;65M8VAR`%]?8WAA7V9I;F%L:7IE`'-T<F-H<@!M96UC;7``;65M<V5T
M`&]P96YD:7(`9V5T=6ED`&%C8V5S<P!M96UC<'D`<W1R8VUP`%]?97)R;F]?
M;&]C871I;VX`86)O<G0`<W1R;F-M<`!?7V5N=FER;VX`7U]R96=I<W1E<E]A
M=&9O<FL`7U]S=&%C:U]C:&M?9W5A<F0`;&EB<&5R;"YS;RXU+C0P`&QI8F,N
M<V\N-@!L9"UL:6YU>"UA<FUH9BYS;RXS`'!A<E]C=7)R96YT7V5X96,`<&%R
M7V)A<V5N86UE`%A37TEN=&5R;F%L<U]005)?0D]/5`!P87)?96YV7V-L96%N
M`'!A<E]C=7)R96YT7V5X96-?<')O8P!P87)?9&ER;F%M90!S:&%?9FEN86P`
M9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``7TE/7W-T
M9&EN7W5S960`7U]D871A7W-T87)T`%]?8G-S7W-T87)T7U\`<VAA7W5P9&%T
M90!X<U]I;FET`%]?96YD7U\`7U]B<W-?96YD7U\`7U]B<W-?<W1A<G0`<VAA
M7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A`'!A<E]S971U<%]L:6)P
M871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R7V1I90!P87)?:6YI=%]E
M;G8`1TQ)0D-?,BXT`$=,24)#7S(N,S0```````````(``0`"``(``@`!``$`
M`0`!``(``P`!``$``@`!``(``0`!``(``@`"``(``0`"``$``0`!``$``0`!
M``(``@`"``(``0`"``(`!``"``$``@`#``(``0`"``(``@`"``(``@`"``$`
M`@`!``(``@`"``$``@`!``(``@`!``(``@`!``,``@`"``(``@`"``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!`````0`!`%`#```0````(````!1I:0T```0`M@0````````!
M``(`1@,``!``````````M)&6!@```P#`!```$````!1I:0T```(`M@0`````
M``"\_0$`%P```,#]`0`7````_/\!`!<````$``(`%P```!0``@`7````&``"
M`!<````@``(`%P```"0``@`7````*``"`!<````L``(`%P```#```@`7````
M.``"`!<````\``(`%P```$0``@`7````R/\!`!4*``#,_P$`%0L``-#_`0`5
M$P``U/\!`!49``#8_P$`$QP``-S_`0`5'0``X/\!`!4>``#D_P$`%28``.C_
M`0`5*```[/\!`!4[``#P_P$`%3P``/3_`0`5/@``^/\!`!5*``#8_@$`%@,`
M`-S^`0`6!```X/X!`!8%``#D_@$`%@8``.C^`0`6!P``[/X!`!8(``#P_@$`
M%@D``/3^`0`6"P``^/X!`!8,``#\_@$`%@T```#_`0`6#@``!/\!`!8/```(
M_P$`%A````S_`0`6$0``$/\!`!82```4_P$`%A0``!C_`0`6%0``'/\!`!86
M```@_P$`%A<``"3_`0`6&```*/\!`!8:```L_P$`%AL``##_`0`6'P``-/\!
M`!8@```X_P$`%B$``#S_`0`6(@``0/\!`!8C``!$_P$`%B0``$C_`0`6)0``
M3/\!`!8G``!0_P$`%BD``%3_`0`6*@``6/\!`!8K``!<_P$`%BP``&#_`0`6
M+0``9/\!`!8N``!H_P$`%B\``&S_`0`6,```</\!`!8Q``!T_P$`%C(``'C_
M`0`6,P``?/\!`!8T``"`_P$`%C4``(3_`0`6-@``B/\!`!8W``",_P$`%C@`
M`)#_`0`6.0``E/\!`!8]``"8_P$`%C\``)S_`0`60```H/\!`!9!``"D_P$`
M%D(``*C_`0`60P``K/\!`!9$``"P_P$`%D4``+3_`0`61@``N/\!`!9'``"\
M_P$`%D@``,#_`0`620``Q/\!`!9*```(0"WI/0$`ZPB`O>@$X"WE!."?Y0[@
MC^`(\+[EV.P!``#&C^(>RHSBV/R\Y0#&C^(>RHSBT/R\Y0#&C^(>RHSBR/R\
MY0#&C^(>RHSBP/R\Y0#&C^(>RHSBN/R\Y0#&C^(>RHSBL/R\Y0#&C^(>RHSB
MJ/R\Y0#&C^(>RHSBH/R\Y0#&C^(>RHSBF/R\Y0#&C^(>RHSBD/R\Y0#&C^(>
MRHSBB/R\Y0#&C^(>RHSB@/R\Y0#&C^(>RHSB>/R\Y0#&C^(>RHSB</R\Y0#&
MC^(>RHSB:/R\Y0#&C^(>RHSB8/R\Y0#&C^(>RHSB6/R\Y7A'_><`QH_B'LJ,
MXDS\O.4`QH_B'LJ,XD3\O.4`QH_B'LJ,XCS\O.4`QH_B'LJ,XC3\O.4`QH_B
M'LJ,XBS\O.4`QH_B'LJ,XB3\O.4`QH_B'LJ,XAS\O.4`QH_B'LJ,XA3\O.4`
MQH_B'LJ,X@S\O.4`QH_B'LJ,X@3\O.4`QH_B'LJ,XOS[O.4`QH_B'LJ,XO3[
MO.4`QH_B'LJ,XNS[O.4`QH_B'LJ,XN3[O.4`QH_B'LJ,XMS[O.4`QH_B'LJ,
MXM3[O.4`QH_B'LJ,XLS[O.5X1_WG`,:/XA[*C.+`^[SE`,:/XA[*C.*X^[SE
M`,:/XA[*C.*P^[SE`,:/XA[*C.*H^[SE`,:/XA[*C.*@^[SE`,:/XA[*C.*8
M^[SE`,:/XA[*C.*0^[SE`,:/XA[*C.*(^[SE>$?]YP#&C^(>RHSB?/N\Y0#&
MC^(>RHSB=/N\Y0#&C^(>RHSB;/N\Y0#&C^(>RHSB9/N\Y0#&C^(>RHSB7/N\
MY0#&C^(>RHSB5/N\Y0#&C^(>RHSB3/N\Y0#&C^(>RHSB1/N\Y7A'_><`QH_B
M'LJ,XCC[O.4`QH_B'LJ,XC#[O.4`QH_B'LJ,XBC[O.4`QH_B'LJ,XB#[O.4`
MQH_B'LJ,XAC[O.4`QH_B'LJ,XA#[O.4`QH_B'LJ,X@C[O.4`QH_B'LJ,X@#[
MO.4`QH_B'LJ,XOCZO.4`QH_B'LJ,XO#ZO.5PM5Y-BK!>2WU$7DS-Z080!JD%
MD@>H!:I\1.M8&V@)DT_P``/_]\+O5TI82Z)8`Y(11N-8!),81@+P7/I42^-8
M'7@`+6/0'>YP+TI+!YA[1!MHQ1P$,+#Q@$_26)+XUC-#\`,#@OC6,W32@`#_
M]VSO2$E)2@-&>40&G'I$"6A08"!HF6!%20>:>4398$1)`2H88'E$66!EW2$=
M!.N"#@/Q#`Q1^`1+3/@$3XY%^='1'#Q,`"!#^"$`*D9\1#I)`)!Y1.!H__=0
M[@`H,=`W30BN?43H:/_WX.X$1C5(,49X1`#P\OA`LS-+>T38:/_W'N[_]Y;N
M,$HB2WI$TU@::`F;6D!/\``#,M$@1@JP<+W_]V+N*DIZ1-!@,+/_]X[N%DL=
M[G`O>T0;:--8@_B&5HSGX&C_]S+NR>>H:!"Q`?!@^]'G'T@Q1GA$`/"^^*A@
M`"C)T//G&TL<2'A$XU@#DQE&__?F[@0AH^<!(/_W..__]\#N`+^NZ@$`V.D!
M`.CI`0`<`0``V.D!`/P````4`0``)`$``/+J`0#VZ@$`."@``"HH``"VZ@$`
M*08``*#J`0"")0``B.H!`/CH`0!<Z@$`MB0``"@!``"D)@``3_``"T_P``X"
MO&I&!+0!M-_X&*`%HYI$3_```PBT!$A:^```__?B[O_WH.W\YP$`,`$``!0P
MG^44()_E`S"/X`(@D^<``%+C'O\O`=7^_^KDYP$```$```9(!TL'2GA$>T1Z
M1(-"`]`%2]-8`[$81W!'`+]"Z0$`0.D!`,+G`0`$`0``"$@)2WA$"4I[1!L:
M>D39#P'KHP%)$`/0!4O36`.Q&$=P1P"_&.D!`!3I`0"4YP$`"`$```BU"DL*
M2GM$>D0;>&NY"4O36".Q"$M[1!AH__>J[O_WO_\&2P$B>T0:<`B]XN@!`&3G
M`0`L`0``CN@!`,+H`0#$YP"_+>GX0QU+'DI[1)M8T_@`D+GQ``\PT`5X@$8/
M1@`M&+\]+12_`24`)1/1V?@`0&RQ3D8J1D%&($;_]SKN$+EC73TK$-!6^`1/
M`"SRT2!&O>CX@P5&%?@!/P`K&+\]*_G1I>L(!>'GINL)!@$U+$2V$#Y@($:]
MZ/B#3$;GYR#G`0`8`0``%TH82WI$$+4$1IZPTUAI1AMH'9-/\``#__<2[:"Y
M!)L#]'!#L_4@3QB_L_6`3PW0#4H,2WI$TU@::!V;6D!/\``#"]$>L!"]`"#Q
MYP(A($;_]S3ML/J`\$`)Z>?_]Z+MH.8!`!P!``!PY@$`-DHW2WI$\+6AL--8
M&V@?DT_P``,0L0-X!$9;N3%*,$MZ1--8&F@?FUI`3_```U/1(;#PO?_WJNP%
M1@`H[M`H1O_WLNT`*#;0PWP`\1,&+BL"T7-X`"ORT,-\+BLRT"!&__<4[0=&
M,$;_]Q#M!T0"-SA&__=<[1Q+.D8"(7M$`98`E`9&__>6[0*I,$;_]S3M`3`P
M1@70!IL#]'!#L_6`3Q?0__?Z[#!&__?&["A&__=\[0`HR-$H1O_W&.T@1O_W
M3NVKYW-X+BO)T;-X`"NVT,7G__>5_^;G__<N[33F`0`<`0``&.8!`&@A``!:
M2EM+>D0MZ?!/#$:#L`5&TUC?^&"!&V@!DT_P``,+>/A$/2L(OP$T($;_][KL
M:48&1BA&__?V_H%&`"A4T/_WL.R&0D?93$L`GUCX`X"_`"MX`"L8OSTK%+\!
M(P`C!]`K1A/X`2\`*AB_/2KYT5L;L!S8^`!@&$3_]^+L\%'HL=CX`#`H1ME9
M$/@!.PMP/2L8OP`K"=!*'!#X`3L11@+X`3L`*QB_/2OVT0I&/2,+<!3X`3L"
M^`$_`"OYT2]*+$MZ1--8&F@!FUI`3_```TK1`["]Z/"/"?'_.13X`3L)^`$_
M`"OYT>GG(TM8^`.`V/@`<#MHF[,[1E/X!"])1@GQ`0D`*OC1`S%/ZH$+'$M[
M1!IHPKE81@$B&F#_]Y+L@D8`*,O0.49/ZHD'6T8Z1O_WX.S(^`"@S?@`D`GQ
M`0D`(TKX*3"$YUE&.$;_]]CL@D;(^````"BQT$_JB0?KYYE&3_`("]+G__=R
M[`"_2.4!`!P!```LY0$`&`$``(SD`0"^Y0$`+>GP00]&*TDK2ZWU@%UY1(*P
M!D8-]8!0!#`-\00(RUA`]O]R048;:`-@3_```R-(>$3_]WSL!!X&W6,>#>L#
M#)SX!"#JN=NY&$L=[G`/.D8Q1GM$&VC`6/_WG.L82@WU@%$52P0Q>D336!IH
M"VA:0$_P``,8T0WU@%T"L+WH\($<1B)&+R%`1O_WB.P`*-O0!T@=[G!?(T9"
M1GA$`&@Q1BA8__?4Z]GG__<.[(+D`0`ZY`$`NN,!`!P!``!,'P``8N,!`#"U
M'>YP3Q)*#TF%L!%(>D1Y1`EH$$L`)7M$$EA@6`])`Y)Y1/_W.NP(20U+>40)
M:`Q*>T1Z1&!8"TD!E7E$`)/_]W[K!;`PO0#D`0#DXP$`]N(!`!`!``!87P``
MIAX``)HA```)#P``J!X```I*@K`*21WN<,]Z1`9("4MX1`!H4EA[1`=)7/@`
M`'E$`9("L/_W`KR4XP$`CN(!`!`!``#N7@``/AX``"5*\+4E2WI$K?4`78>P
M#?4`40.LTU@4,0WU@%8;:`M@3_```__WP.L=2@(A'4L0-GI$S>D``GM$($9!
M\@$"__?,ZR!&3_2`4C%&__>ZZP0>N+\`)0S;9QPX1O_W>NL%1C"Q.T8Q1B)&
M__<*ZP`C*U4-2@WU`%$)2Q0Q>D336!IH"VA:0$_P``,$T2A&#?4`70>P\+W_
M]V+K5N(!`!P!```P'@``'AX``.+A`0#_]ZB_6THMZ?!/!D9:2WI$K?6$78.P
M64@-]815#?$0"--8#$9X1$%&!#4;:"M@3_```__W*?TO(05&,$;_]X#JP+%/
M2#%&>$3_]PS^,$9-2@WUA%%(2P0Q>D336!IH"VA:0$_P``-`\(.`#?6$70.P
MO>CPCR!&__<$ZT-)>43_]R3K!$8`*-S0(W@-\8@*W_C\D*KQ!`?Y1``K2-`E
ML2%&*$;_]W;KN+,@1O_WK.I#'B-$@T:<0CZ_(Q@`(6`<`],*X)A"&7`#T!/X
M`2TO*OC0($;_]YCJ@T8P1O_WE.I81`$PL/6`7ZS2*4@"(4M&3_2`4GA$`)3-
MZ0$&.$;_]Q;K048X1O_WM.HPN5KX:#P#]'!#L_4`3Q?0'DD`('E$__?4Z@1&
M`"B,T"-X`"NVT=6Q*W@N*P30&$Q/\`$+?$3+YVMX`"OHT/;G`2$X1O_W/.H`
M*.'1$4@Y1GA$__>#_3A&__>.ZG/G#DQ/\`$+?$2SY__WGNJBX0$`'`$``)@=
M``""'0``6.$!`%P=``!&'0``\AP``+P<``!\'```<!P``$P<```0M2\A!$;_
M]^[I`+%$'"!&O>@00/_W8+H[2O"U.TMZ1*WU@%V#L`WU@%'36`0Q&V@+8$_P
M``,`*#S0`W@%1@`K.-#_]P[J0AP$1K+U@%]'V`&O*48X1O_W$.IC'CM$GT(+
MTC@9#?$%`@`A`N"00@%P`]`0^`$]+ROXT"\A.$;_][+I>+.X0H2_`",#<#A&
M__<FZA]*#?6`41Q+!#%Z1--8&F@+:%I`3_```RO1#?6`70.P\+T72@WU@%$4
M2P0Q>D336!IH"VA:0$_P``,:T1)(>$0-]8!=`["]Z/!`__?\N0`@UN<-2@WU
M@%$(2P0Q>D336!IH"VA:0$_P``,"T0A(>$3FY__W`NKNWP$`'`$``'#?`0!.
MWP$`1!L``![?`0`4&P``S$K-2WI$<+7,3H*PS$W36'Y$;$9]1!MH`9-/\``#
M(48P1O_WS?NPL<9+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A
M1C!&__>W^P`HZ-&\3GY$(48P1O_WK_NPL;=+`)CK6!EH`>N``UIH0?@@(``J
M[]`$,UIH0_@$*P`J^M$A1C!&__>9^P`HZ-&N3GY$(48P1O_WD?NPL:A+`)CK
M6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__=[^P`HZ-&@3GY$
M(48P1O_W<_NPL9E+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A
M1C!&__==^P`HZ-&23GY$(48P1O_W5?NPL8I+`)CK6!EH`>N``UIH0?@@(``J
M[]`$,UIH0_@$*P`J^M$A1C!&__<_^P`HZ-&$3GY$(48P1O_W-_NPL7M+`)CK
M6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__<A^P`HZ-%V3GY$
M(48P1O_W&?NPL6Q+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A
M1C!&__<#^P`HZ-%H3GY$(48P1O_W^_JPL5U+`)CK6!EH`>N``UIH0?@@(``J
M[]`$,UIH0_@$*P`J^M$A1C!&__?E^@`HZ-%:3GY$(48P1O_WW?JPL4Y+`)CK
M6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__?'^@`HZ-%,3GY$
M(48P1O_WO_JPL3]+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A
M1C!&__>I^@`HZ-$^3GY$(48P1O_WH?JPL3!+`)CK6!EH`>N``UIH0?@@(``J
M[]`$,UIH0_@$*P`J^M$A1C!&__>+^@`HZ-$P2"%&>$3_]X3Z`488L2U(>$3_
M]VS[+$@A1GA$__=Y^@%&&+$J2'A$__=A^RE((49X1/_W;OH!1K"Q)DAX1/_W
M5OLE2A%+>D336!IH`9M:0$_P``,5T2%)(DAY1'A$`K"]Z'!`__=#NQ]((49X
M1/_W4/H!1@`HY-`<2'A$__<W^]_G__=:Z.3>`0`<`0``$!L``-3>`0`8`0``
MU!H``*`:``!P&@``/!H``!`:``!P&0``I!D``'09``!$&0``C!@``-88``"R
M&```U!@``-P8``#>&```"A@``/3;`0#8&```/A@``+(8```\&```$TH42WI$
M`+432(.PTUAX1&E&&V@!DT_P``/_]P/Z0+$`>``H&+\P*`R_`2``((#P`0`*
M2@=+>D336!IH`9M:0$_P``,"T0.P7?@$^_[W_N](VP$`'`$``+H7```6VP$`
M#[3?^#3``+4,2OQ$@[`$JPM)#$A<^`(@>402:`&23_```E/X!"L`DPA8`B$`
M:/[WK.__(/_W4.CBV@$`'`$``-3:`0`@`0``+>GP1P(A/TRM]8`]`"*&L'Q$
M#?6`-0`C%#6`1@"1.DEA6`EH*6!/\``!_O>P[P$X8?$`!_H7@.H"`YL:F[)3
M0)L:8NL"`L8:9^L"!P`O2]M/\`@)P/(!"0.M`"$R1CM&0$8`D?[WDN^Q\?\_
M"+^P\?\_0=!*1BE&0$;^]QKO0QPVT`<H)MD(."P8(]+?^'R@^D0"X`$\K$(<
MTP@B448@1O[WL.X`*/719!N@&4?KY'$72@WU@#042Q0T>D336!IH(VA:0$_P
M``,:T0WU@#T&L+WH\(>V]8`V9_$`![?Q_S\(OQ;U@#^XT4_P_S`!1M_G"$AX
M1/_W8/\'2'A$__=<__[W4.^4V@$`'`$``%#;`0#JV0$`OA8``*86```(M?[W
MNN[^]_SN`+$`:`B])DHG2WI$\+4F3X>P!4;36']$!*DX1AMH!9-/\``#__<7
M^1"Q`W@$1HNY'TH<2WI$TU@::`6;6D!/\``#+-$;2"E&>$0'L+WH\$#_]^^Y
M*$;^][SN!D8@1O[WN.X&1`(V,$;^]P3O$DL223)&>T0"E'E$`)4!D0(A!$;^
M]SSO#DH'2WI$TU@::`6;6D!/\``#!+\A1CA&U=#^]^[N=-D!`!P!``"`%@``
M2MD!`$X6```X%0``,!4``/;8`0`MZ?!/W_AL),&PW_AL%'I$W_AH5'E$)J\(
MDGU$W_A@)`7Q#`,'D`7Q&`PLK#`U)D8-\:0)BE@-\2@($F@_DD_P``*3Z`<`
MA^@'`+SH#P`/QISH`P"&Z`,`E>@'`(GH!P#?^"`$049X1/_WE/@@L0-X!48`
M*T#P?H'^]QCN_O=:[@`H`/"O@`9H`"X`\*N`,$;^]S[N0@`"\0$*4$;^]XCN
M!48P>``H`/!W@=-&"97?^-B3^4121DM&`)`"(2A&`C7^][KNTT46^`$/6T8X
MOU-&H^L*`JKQ`@H",JKK`PJ:0BR_DD2:1``HY-'H2'A$`N!4^`0/B+%!1O_W
M3/@%1@`H]M`#>``K\]#_]X;X`"COT"A&_O<\[@1&B+E7^`1+=+$C>``K`/`0
M@2!&__=U^``H\]`@1O[W*NX$1@`H[=`@1O[WYNT)G09&*$;^]^+M!D0&\@1&
M,$;^]RSNS4L'1C)&>T0"D\M+`B$#E7M$`9/*2P"4>T3^]V#N3_3@<3A&_O<V
M[0$P!='^]Y;N`6@1*4#PXX!!1CA&_O=@[01&`"@\T+Y)")@'F[Y*0%@"(1MH
M>D0`EP!H_O<([@`ENDJP2WI$TU@::#^;6D!/\``#0/!,@2A&0;"]Z/"/_O?8
M[09&`"A`\+2`6?@$"UBQ04;^]]+_`"CWT`-X`"ONT5GX!`L`*//1J4X-($_P
M#0O^]]+M?D0%1@F0VD93($GG#IL#]'!#L_6`3[S1$)W^]T#MA4*WT0Z;P_,(
M`[/UX'^QT3!&_O>X[05&F4A!1GA$_O>C_P%&`"@`\*.`!YL8:/_W6?J#1@`H
M`/";@%A&_O=2[8%&`R@0V8])!#A81'E$_O<0[DBYN?$$#P#PV8#91!GX!3PO
M*P#PTX"'2$%&>$3^]WO_(+$#>#`K&+\`*P;16$8`(?[W3NV`1@`H==%_28!(
M>43?^`"B>$3?^/R1__=2^-_X^('^]YKM?4M^2@(A>T3-Z0!S?$MZ1`*0*$8#
MDGM$,D;Z1/E$^$3^]Z#M$^#^]]SM`V@1*Q71_O>`[0$TA$931C)&`B$H1LWI
M`TG-Z0&,`)?^]XSM3_3@<2A&_O=@[`$PY-`X1O[WQ.QH2"E&>$3_]QCX*$;_
M]__]..<<1OCF_O?@[$(``O$!"J#F4$H(F`>;@%@;:%Y*S>D`<0(A>D0`:/[W
M+.TAY__WYOU92D%+>D336!IH/YM:0$_P``-MT2A&0;"]Z/!/_O?XO`F5IN8'
MF]/X`+!@Y__W./V!1K'Q``J#V[#Q"@)/\``+:O$``T!&S?@`L/[W\.PRJ08B
M0$8'D?[W?.P'F08H2=$RFD_TAD/$\D$SFD)_]&BOBHA$\DA3FD)_]&*ON?$R
M`D!&:O$``S2LS?@`L/[WSNQ`1B@B(4;^]USL*"@JT3-+,D8S22A&>T3-Z0!S
M,4MY1`*4`Y%[1`(AC?CXL/[W`.UZYP>;T_@$D+GQ``\_]":O2$;^]V+L`RA_
M]B"O)DD$.$A$>43^]Q[M`"@(O\M&%>?^]ZCL(4AX1/_WKORNV`$`J-@!`-[9
M`0`<`0``8A0``#H5``"8%```H!0``(83``""%```(`$``)84``#^U@$`UA,`
M`%`4```H%```H!(``/@2``!V$@``[A,``)04``#^$0``%A(``*(4``#B$P``
MCA$``)X2``!`U0$`TA```%X3``"0$@``3A(``$(2``!D265*>41PM5I+@K`=
M[G!/BEAI1F%(;D82:`&23_```GM$&VAX1.58E?AH,(7X:3#^]S3^$+$#>#$K
M?-#_]T[Z34M[1!MHY5A522A&`R,!(GE$_O>2ZP5&<+$":4=+>T0;:!%H3TK@
M6'I$_O>2ZRMI&6B+:%L":M1!20,C`2)Y1`EH8%A(27E$_O=VZP5&>+%&2#%&
M>$3^]P'^*VD"1AEH`"A,T#=+>T0;:.!8_O=PZS5+`2(^27M$&VAY1.58*$;^
M]S;K.TH!1BA&>D0Z3?[W8.LN2SE(?41[1!MH`")X1#%&XUB#^&D@_O?8_01&
MJ&"PL4_TX'$@1O[W_.I"'`-&$2@8OP$J*]@M2B-+>D336!IH`9M:0$_P``,?
MT0*P<+UH:/_W\?P$1JA@`"CAT25(>$3^]^CK0W@`*X70?N<B2PA&>T1;:!EH
M_O=8_[#G$$M[1!MHX%C^]Z3KC>?^][+K&DDB1AI(>41X1$EH"6C^]\KK`+^P
MU`$`CM0!`'+4`0!2U`$`*M0!`!K4`0#XTP$`@-,!`,#3`0`<`0```!```*@1
M``"4$0``?A$``$@/``!.$0``5A$``&[4`0#R#@``N-(!`/@0```"U`$`WM,!
M`.00```I2BI+>D0PM01&*4B#L--8:49X1!MH`9-/\``#_O=4_7"Q`W@P*QB_
M`"L,OP$C`".#\`$#`"P,OP`C`_`!`UNY'$H:2WI$TU@::`&;6D!/\``#)]$#
ML#"](W@`*_#0($;_]\SX+R$%1O[WKNH`L44<*$;^]R;K$$D$(GE$_O=\ZP`H
MW=$-2@E+>D336!IH`9M:0$_P``,%T2!&`["]Z#!`_O>*O?[W).OLT0$`'`$`
M`%H.``"LT0$`N@X``&C1`0`MZ?!/`T;?^!!*K?4K?0/Q@`??^`@Z?$0(J0`F
M`I`*1D`PO$;C6!MHJ9-/\``#4.D"=%9@UF`0,C^Z0O@0?",*)0(#]']#"#!#
MZA1C!?1_!4/J!&.$14/J!0-"^`@\YM'=Z2*""JPFFPWQB`L`DR2H)JT!]0)S
M`Y`@1@25S>D%00UHS?@<L)-&W?B4X-WXG,`)G]WX+*`DGMWX*)``F0&3`>"1
M1II&`)$`(]#I#A10^`@O0V=10('J"`&P1D-H:4``GDU&7$"$Z@L$\T9\0.9&
M3^K1?$D83.I$#`&<0>H,`5=&3_``#*!"`6?:T0.;`IC=^!RP'6@$F]WI!4';
M^`!@&VC0Z0%[`Y/0Z0,ZT/@`P$_JFPX*:"%H3NJ#?H1I1_:9$\7V@B,`E`1J
MTAA/ZMQ@`91`ZD<0$AD`G$#J3!""&$[JBWZ*Z@0`3^J<"0#J"P!)ZH=Y8$!)
MZHQY$AB*Z@X`R1@`Z@P`"1G=^#"`@.H*``Z?"!B.Z@D!&.L#"!%``.OR8!CK
M"@B!Z@X!3^JR`ACK`0'_&!?K#@@!Z_!GB>H"`=WX0.`!0$_JL`"!Z@D!&.L!
M`1[K`PX>ZPD)`>OW;H+J``'=^$B`.4!/ZK<'44`9ZP$!&.L#"!CK`@F`Z@<"
MW?A0@`+J#@(!Z_YA0D!/ZKX.&>L"`ACK`P@8ZP`)`NOQ8(?J#@+=^%B`"D!/
MZK$!>D`9ZP("&.L#"!CK!PD"Z_!GCNH!`MWX8(`"0$_JL`""Z@X"&>L"`ACK
M`P@8ZPX)`NOW;H'J``+=^&B`.D!/ZK<'2D`9ZP("&.L#"!CK`0D"Z_YA@.H'
M`MWX<(`"Z@X"3^J^#D)`&>L"`ACK`P@8ZP`)`NOQ8(?J#@+=^'B`"D!/ZK$!
M>D`9ZP("&.L#"!CK!PD"Z_!GCNH!`MWX@(`"0$_JL`""Z@X"&>L"`ACK`P@8
MZPX.`NOW:('J``(Z0$_JMP=*0![K`@+V&'88@.H'`0'J"`$"Z_AB04!/ZK@(
M<1CM&"T8`>OR8(?J"`$10$_JL@)Y0(CJ`@9I&`.=!D`!Z_!A[!@HG4_JL`"&
MZ@@&Y!F"Z@`'I!GM&!7K"`8/0"J=!.OQ9%=`3^JQ`?89@.H!#NT8#NH$#J\8
M+)U/ZK0"CNH`#@;K]&87ZPX$@>H"!^T8+1@W0"Z83T`$Z_9D[QE/ZK8&PQA;
M&(+J!@$A0#"=44`'Z_1N6!A.]J$SQO;98T_JM`05ZP,(,ID8ZP((ANH$`@#K
M_F""Z@X"3^J^!1CK`@B$Z@4.RA@TGPCK\&&.Z@`.DAE/ZK``$NL.`C:>_QB%
MZ@`.`NOQ8H[J`0X\&4_JL0$4ZPX$.)_V&(#J`0X$Z_)DCNH"#G493^JR`A7K
M#@4ZGH'J`@[_&([J!`X_&`7K]&`7ZPX'3^JT!!;K`PX\G1[K`0X'Z_!A@NH$
M!SZ>1T!/ZK``'NL'#N\8OQ@.Z_%BA.H`#D"=CNH!#D_JL0$7ZPX'%NL##A[K
M!`X'Z_)D@.H!!T*>5T!/ZK("'NL'#N\8/Q@.Z_1@@>H"#D2=CNH$#D_JM`07
MZPX'@NH$#O88!^OP9X[J``YV&$_JL``6ZPX&1IF$Z@`.[1@&Z_=FCNH'#JT8
M3^JW!Q7K#@5(FLD8@.H'#@7K]F6.Z@8.#!E/ZK8&%.L.!$J9TAB'Z@8.!.OU
M9([J!0X0&$_JM040ZPX`3)J&Z@4.R1@`Z_1@CNH$#LD93^JT!!'K#@%.GX7J
M!`[2&`'K\&&.Z@`.DAE/ZK``$NL.`E">_QB$Z@`.`NOQ8H[J`0Y]&4_JL0$5
MZPX%4I_V&(#J`0XT&8[J`@X%Z_)F%.L.!$_JL@(7ZP,.5)T>ZP`.@>H"`'!`
M!.OV9![K``Y/ZK8`[1B"Z@`&:1A6G69`#NOT;HD93^JT!.L86)V;&(#J!`*"
MZ@X"3^J^!YH82_;<0\CV&W,!Z_YA[1A$Z@<.6IXH&`[J`0X$Z@<%3NH%#@+K
M\6(0ZPX.3^JQ`?`87)T`&4?J`00.Z_)F%$`'Z@$.3^JR`D3J#@0!Z@(()!CM
M&$'J`@`5ZP<.,$`$Z_9E7IQ`Z@@`3^JV!A#K#@[@&`[K]61`&$+J!@$"Z@8.
M*4!@GT'J#@%/ZK4%"1@!Z_1@_QA&Z@4!!NH%#KH8(4!BGT_JM`1!Z@X!!>H$
M"(D8_QA%Z@0"%^L&#@)`9)\!Z_!A0NH(`D_JL``2ZPX"_Q@$Z@`.?1D"Z_%G
M1.H``F:>"D!/ZK$!0NH.`MWXH.%5&?(8$AE`Z@$$3^JW!@7K]V4\0`#J`0<\
M0T'J!@>B&![K`P0D&`'J!@YJF"]``NOU8D?J#@=/ZK4%/!E&Z@4'P!@$Z_)D
M!NH%#D`8%T!/ZK(!;)I'Z@X'/QA%Z@$`TA@@0)(9!^OT9@7J`0=/ZK0$.$-!
MZ@0'@!ANF@'J!`XW0-(8`.OV8%49<)I'Z@X'3^JV!G\9TAA5&`?K\&%$Z@8'
M!.H&#G*:!T!'Z@X'3^JP`'T9TA@2&4;J``0&Z@`'#$`\0P7K\66D&'2:3^JQ
M`03K]632&$#J`0<`Z@$.EADO0'::1^H.!T_JM06_&=(8%A@'Z_1@0>H%!P'J
M!0YXFB=`1^H.!T_JM`2_&47J!`;2&`9`4A@'Z_!A!>H$!T_JL``^0P*?MA@`
M(@3J``X&Z_%F>F#Z8'J:TAA5&0`B>F'Z843J``=\F@]`1^H.!T_JL0%_&=(8
M0.H!!0?K]F<2ZP0.-4!/ZK8$?IH`Z@$&-4,!Z@0&%>L.!=,8&QA!Z@0`.$"`
MFC!#!>OW9<`83/+6$\SV8B-/ZK<'UAB"FG88A.H'`6E``.OU8'883^JU!=(8
MA^H%`109A)I!0`;K\&9D&$_JL`#2&(7J``'7&8::!.OV9'%`?QA/ZK8&T1B(
MFDD9!^OT98#J!@=G0$_JM`3)&=<8/QB*FH;J!``!Z_5A:$!/ZK4%/QC0&(`9
MC)H'Z_%FA.H%!T]`3^JQ`<`9UQ@_&8Z:A>H!!`#K]F!T0#\93^JV!-88D)IV
M&0?K\&6!Z@0'1T!/ZK``]AG7&'\8DIH&Z_5AA.H`!FY`3^JU!;\9UA@V&92:
M!^OQ9(#J!0=/0$_JL0'V&=<8/QB6F@;K]&"%Z@$&9D!/ZK0$OQG6&'89F)H'
MZ_!E@>H$!T=`3^JP`/89UQA_&)J:!NOU883J``9N0$_JM06_&=88-AF<F@?K
M\62`Z@4'3T!/ZK$!]AG7&#\8GIH&Z_1@A>H!!F9`3^JT!+\9UAAV&:":!^OP
M98'J!`='0$_JL`#V&=(85Q@&Z_5AHIJ$Z@`&;D!/ZK4%OQG2&!89!^OQ9(#J
M!0>DFD]`3^JQ`?<9`IX'Z_1GTA@0&`KKMP(R8:::A>H!!F9`3^JT!(`9TQB!
MZ@0"`.OW8'I`$^L,`P*?6QF;&!#K"P(#Z_!C`)@[8`&;)!BZ8``B>F+)&`M*
M"4MZ1+QA.6+36!IHJ9M:0$_P``,#T0WU*WV]Z/"/_?<.[@"_&M$!`!P!```Z
MQP$`"+6`(/WW_.V?[0Y[`"*"9X#M`'N?[0U[@.T">Y_M#7N`[01[G^T->X#M
M!GN?[0U[@.T(>Y_M#7N`[0I[@.T,>PB]`+\!(T5G`````(FKS>\`````_MRZ
MF`````!V5#(0`````/#ATL,````````````````MZ?!'!4861H!J`",/1O07
MU>D,(0#KQ@R$1>AJ<^L```+2`3)!\0`!J&\%\3@*Q>D*PW,/0^K$`YL8*V-!
MZU1Q:6.HNS\N*]VF\4`(M@D&\?\Y/$8'ZX86(T921@3Q0`'3^`#`$#-3^`Q,
M$#)3^`@,4_@$[(M"0O@$[$+X$,Q"^`Q,0O@(#.O1'$8H1O_W;/JT0N'10#>H
MZXD6*/`_"$=$,D8Y1E!&_?<N[:YGO>CPA\#Q0`0%\3@*M$)01*B_-$8Y1B)&
M_?<>[:MO(T2K9T`K[-$H1C8;)T3_]T;ZLN<`ORWI\$$!\3@'#$:+:@5&#FN`
M(9/Z@_C#\\4#-KI:'+@8."KY5$3=PO%``@`A_?>D["!&__<I^CA&."(`(?WW
MG.P@1L3I'&C_]Q_ZXW@K<"!&8XAK<"-H&PJK<"-HZW#C>BMQ8XEK<:-H&PJK
M<:-HZW'C?"MR8XIK<B-I&PJK<B-IZW+C?BMS8XMK<Z-I&PJK<Z-IZW.4^",P
M*W1CC&MT(VH;"JMT(VKK=+WH\$']]X*\PO$X`@`A_?=@[,'G`DM[1!MH_?<1
MO0"_,L8!``A`+>D(@+WH`0`"`#X```!!````#````$$````1````00```"<`
M``!!````-@```$$````#````00````8```!!````%0```$$````/````00``
M``X```!!````)@```$$````3````00```"D```!!`````@```$$````9````
M00````H```!!````"P```$$``````````````"5S+R5S````+W!R;V,O<V5L
M9B]E>&4``$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z
M.E!!4CHZ0D]/5``````O<')O8R\E:2\E<P!E>&4`+@```%!!4E]414U0````
M`%!!4E]04D]'3D%-10`````Z````)7,E<R5S```O````4$523#5,24(`````
M4$523$Q)0@!015),-4]05`````!015),24\``%!!4E])3DE424%,25I%1`!0
M05)?4U!!5TY%1`!005)?0TQ%04X```!005)?1$5"54<```!005)?0T%#2$4`
M``!005)?1TQ/0D%,7T1%0E5'`````%!!4E]'3$]"04Q?5$U01$E2````4$%2
M7U1-4$1)4@``4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`````
M,0```&QS965K(&9A:6QE9`````!R96%D(&9A:6QE9`!,1%],24)205)97U!!
M5$@`4UE35$5-```E,#)X`````"5S)7,E<R5S`````'!A<BT`````)7,Z(&-R
M96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R
M;F\])6DI"@``)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F
M92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI
M"@``4$%42`````!P87)L`````"YP87(`````<VAO<G0@<F5A9```)7,E<V-A
M8VAE+25S)7,``"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S````
M`!@```!P97)L`````#````!005(Z.E!A8VME<CHZ5D524TE/3@`````Q+C`V
M,P```%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y`````"5S.B!C
M<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H`````+64``"TM``!54T52`````%5315).04U%````
M`%1%35!$25(`5$U0`"]T;7``````979A;"`G97AE8R`O=7-R+V)I;B]P97)L
M("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@
M<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@
M)$9)3$5?;V9F<V5T7W-I>F4L("1C86-H95]N86UE7W-I>F4I.PI"14=)3B![
M"B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["B1&24Q%7V]F9G-E=%]S:7IE
M(#T@-#L@("`C('!A8VLH(DXB*0HD8V%C:&5?;F%M95]S:7IE(#T@-#`["B10
M2UI)4%]-04=)0R`](")02UPP,#-<,#`T(CL*?0IS=6(@9FEN9%]P87)?;6%G
M:6,*>PIM>2`H)&9H*2`]($!?.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R
M-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D9F@["FUY("1P;W,@/2`H)'-I
M>F4M,2D@+2`H)'-I>F4M,2D@)2`D8VAU;FM?<VEZ93L@("`@("`C($Y/5$4Z
M("1P;W,@:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ90IW:&EL92`H)'!O
M<R`^/2`P*2!["G-E96L@)&9H+"`D<&]S+"`P.PIR96%D("1F:"P@)&)U9BP@
M)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RD["FEF("@H;7D@)&D@
M/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*<F5T=7)N("1P
M;W,@*R`D:3L*?0HD<&]S("T]("1C:'5N:U]S:7IE.PI]"G)E='5R;B`M,3L*
M?0IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE
M0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@
M1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&
M:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA
M;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A
M<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I
M(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T
M96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*
M;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A8
M6%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL
M"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA
M;64@/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[
M('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*
M:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P
M(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC
M;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B
M)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO
M=71S*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@
M8VQE86YU<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.('L*26YT97)N86QS
M.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/
M5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[
M4$%27T1%0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]
M?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@
M/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D
M96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O
M)RDL"BD["E]S971?<')O9VYA;64H*3L*;W5T<RAQ<5M<)'!R;V=N86UE(#T@
M(B1P<F]G;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO=71S*'%Q6UPD14Y6
M>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*;7D@*"1S=&%R=%]P
M;W,L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI.PI-04=)0SH@>PIL;V-A;"`D
M4TE'>U]?5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ
M<F%W)RP@)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I
M;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE<F4@87,@:70@
M<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D;6%G:6-?<&]S
M(#T@9FEN9%]P87)?;6%G:6,H*E]&2"D["FEF("@D;6%G:6-?<&]S(#P@,"D@
M>PIO=71S*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#
M(B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,["GT*;W5T<R@B
M1F]U;F0@4$%2(&UA9VEC(&%T('!O<VET:6]N("1M86=I8U]P;W,B*3L*<V5E
M:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M(&QE;F=T
M:"@B7#!#04-(12(I+"`P.PIR96%D(%]&2"P@)&)U9BP@;&5N9W1H*")<,$-!
M0TA%(BD["FEF("@D8G5F(&YE(")<,$-!0TA%(B`F)B`D8G5F(&YE(")<,$-,
M14%.(BD@>PIO=71S*").;R!C86-H92!M87)K97(@9F]U;F0B*3L*;&%S="!-
M04=)0SL*?0IO=71S*'%Q6T-A8VAE(&UA<FME<B`B)&)U9B(@9F]U;F1=*3L*
M<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92P@,#L*
M<F5A9"!?1D@L("1B=68L("1&24Q%7V]F9G-E=%]S:7IE.PIM>2`D;V9F<V5T
M(#T@=6YP86-K*").(BP@)&)U9BD["F]U=',H(D]F9G-E="!F<F]M('-T87)T
M(&]F($9)3$5S(&ES("1O9F9S970B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@
M+2`D1DE,15]O9F9S971?<VEZ92`M("1O9F9S970L(#`["B1S=&%R=%]O9E]&
M24Q%7W-E8W1I;VX@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A
M9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!R
M96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2![
M"G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").
M(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7%;56YP86-K
M:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN
M86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@
M*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<
M+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N
M<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A
M?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A
M=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&
M=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ
M.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<V4@>PHD
M36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]
M/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E<75I<F5?;&ES='LD
M9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.
M0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I
M9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2`D36]D=6QE
M0V%C:&5[)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN9F\["F1E;&5T92`D
M<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D
M97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E
M9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN
M97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z("0A
M(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*
M)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL
M96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB
M=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*;W!E;B!M>2`D9F@L
M("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I
M;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN
M9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.
M0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q
M=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL
M93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?
M;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N
M86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O
M:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE
M('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*
M?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FEF("@D8G5F
M(&YE("102UI)4%]-04=)0RD@>PIO=71S*'%Q6TYO('II<"!F;W5N9"!A9G1E
M<B!&24Q%('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!
M1TE#(#L*?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@
M("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U
M="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6
M>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S
M96-U<FET>2!P<F]B;&5M*0II9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=
M(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD
M(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N
M:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF
M("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!
M4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS
M92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW
M:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4
M=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?
M=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D
M,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@
M)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@
M*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E
M<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I
M('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO
M9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B
M)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]
M("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[
M)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR
M97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE
M<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8[
M"F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@
M*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z
M.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H
M0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@
M)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F
M:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@
M9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM
M>2`E;65T85]P87(@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z
M:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R
M.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;
M7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D("1P87(I('L*;W!E
M;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(')E860@
M<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E860@)'!H+"`D8G5F
M+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F:6QE72!U;FQE<W,@
M)&)U9B!E<2`D4$M:25!?34%'24,["F-L;W-E("1P:#L*?0I#<F5A=&50871H
M*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I
M;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U)$5U(H*2!\($E/.CI&:6QE
M.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F
M:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L
M(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1S=&%R=%]O9E]&24Q%7W-E
M8W1I;VXI('L*<F5A9"!?1D@L("1L;V%D97(L("1S=&%R=%]O9E]&24Q%7W-E
M8W1I;VX["GT@96QS92!["FQO8V%L("0O(#T@=6YD968["B1L;V%D97(@/2`\
M7T9(/CL*?0II9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]
M?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L
M("0P*3L*?0HD9F@M/G!R:6YT*"1L;V%D97(I"F]R(&1I92!Q<5M%<G)O<B!W
M<FET:6YG(&QO861E<B!T;R`B)&]U="(Z("0A73L*:68@*"1B=6YD;&4I('L*
M<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC
M(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET
M92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD
M"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*
M<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I
M;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L
M('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML
M:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@
M)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@
M>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@
M/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC
M*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE
M+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\
M7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L
M94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA
M<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B
M)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I
M;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF
M("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD[
M"F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D
M9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*
M:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*
M96QS92!["FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@)'1H+"`G/#IR87<G
M+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C
M;VYT96YT(#T@/"1T:#X["F-L;W-E("1T:#L*4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@
M(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\
M86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY
M*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%
M(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X
M>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@
M)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT
M*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!E;6)E9&1E9"!&24Q%('1O("(D
M;W5T(CH@)"%=.PIO=71S*'%Q6U=R:71T96X@87,@(B1N86UE(ETI.PI]"GT*
M:68@*"1Z:7`I('L*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('II
M<"!P87)T(&]F("(D;W5T(ET["GT*:68@*"1M971A7W!A<GMC;&5A;GTI('L*
M)&9H+3YP<FEN="@B7#!#3$5!3B(I.PI]"F5L<V4@>PII9B`H(61E9FEN960@
M)&-A8VAE7VYA;64I('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D[
M"G-E96L@)&9H+"`P+"`P.PHD8W1X+3YA9&1F:6QE*"1F:"D["G-E96L@)&9H
M+"`P+"`R.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C
M:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@)&-A8VAE7VYA;65?
M<VEZ93L*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@D8V%C:&5?;F%M95]S:7IE
M("T@;&5N9W1H("1C86-H95]N86UE*3L*)&9H+3YP<FEN="@D8V%C:&5?;F%M
M92P*(EPP0T%#2$4B*3L*?0IM>2`D;V9F<V5T(#T@)&9H+3YT96QL("T@;&5N
M9W1H*"1L;V%D97(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D;V9F<V5T*2P*
M)%!!4E]-04=)0RD["B1F:"T^8VQO<V4@;W(@9&EE('%Q6T5R<F]R('=R:71I
M;F<@=')A:6QE<B!O9B`B)&]U="(Z("0A73L*8VAM;V0@,#<U-2P@)&]U=#L*
M97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I
M>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!
M<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S
M(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R
M)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI:
M:7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ
M6FEP+3YN97<["B@D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O
M9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R
M<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E
M.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI
M8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II
M<#L*;W5T<R@B17AT<F%C=&EN9R!Z:7`N+BXB*3L*:68@*&1E9FEN960@)$5.
M5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A
M"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@
M:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M
M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@
M;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_
M"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S
M=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@
M)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@
M)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I
M;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@
M(B1D97-T7VYA;64B72D["GT@96QS92!["F]U=',H<7%;17AT<F%C=&EN9R`B
M)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(N+BY=*3L**"1M96UB97(M
M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*2`]/2!!<F-H:79E.CI:
M:7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!E>'1R86-T:6YG('II<"!M
M96UB97(@=&\@(B1D97-T7VYA;64B73L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M
M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI
M8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8[
M"E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE
M(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM
M3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O
M9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"![
M"FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@
M*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I
M;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@[
M"D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@
M(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE
M<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@
M:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E
M<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y
M.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q
M=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI4
M96UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E
M<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z
M.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV
M93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q
M=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A
M=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER
M92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I
M<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N
M>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D
M0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R
M;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?
M<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD
M("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*
M<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q
M=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H
M($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P
M871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*
M;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D
M969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@
M*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD
M969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92![
M"B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@
M)U-94U1%32<["GT*;7D@)'-T;7!D:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP
M87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L
M(#`W-34["FUY("1C86-H95]D:7(["FEF("@D14Y6>U!!4E]#3$5!3GTI('L*
M)&-A8VAE7V1I<B`](")T96UP+20D(CL*?0IE;'-E('L*;W!E;B!M>2`D9F@L
M("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R
M;V=N86UE(CH@)"%=.PII9B`H*&UY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M
M86=I8R@D9F@I*2`^/2`P*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)
M3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*;7D@)&)U
M9CL*<F5A9"`D9F@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U
M9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,
M15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I"BT@)&-A8VAE7VYA
M;65?<VEZ92P@,#L*<F5A9"`D9F@L("1B=68L("1C86-H95]N86UE7W-I>F4[
M"B1B=68@/7X@<R]<,"\O9SL*)&-A8VAE7V1I<B`](")C86-H92TD8G5F(CL*
M?0I]"F-L;W-E("1F:#L*?0II9B`H(21C86-H95]D:7(I('L*)&-A8VAE7V1I
M<B`](")T96UP+20D(CL*)$5.5GM005)?0TQ%04Y](#T@,3L*?0HD<W1M<&1I
M<B`N/2`B)'-Y<WM?9&5L:6U])&-A8VAE7V1I<B(["FUK9&ER("1S=&UP9&ER
M+"`P-S4U.PHD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIL87-T.PI]"B1P
M87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]4
M14U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*;7D@*"1N86UE+"`D
M8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T
M96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N
M86UE(#T@(B1F=6QL;F%M92XD)"(["FUY("1F:#L**&]P96X@)&9H+"`G/CIR
M87<G+"`D=&5M<&YA;64I"B8F("AP<FEN="`D9F@@)&-O;G1E;G1S*0HF)B`H
M8VQO<V4@)&9H*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R`B)'1E;7!N86UE
M(CH@)"%=.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO
M9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T
M96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G
M;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.
M5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*
M?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN
M9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N
M86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)'-Y
M<WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R
M(&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^/2`P*2!["FEF("AO
M<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F
M:#L*?0II9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X97TB*2!["B1P<F]G;F%M
M92`N/2`D<WES>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@
M*'-P;&ET("]<421S>7-[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE
M>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[
M4$%27U1%35!].PHD9&ER(#U^(',O7%$D<WES>U]D96QI;7U<120O+SL**"@D
M<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X
M97TB*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D
M<WES>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P
M<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G
M;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE
M('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L
M("1S>7-[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)'-Y<WM?9&5L
M:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T
M8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#
M=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*
M)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D96QI;7U<12DO)'!W
M9"1S>7-[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M
M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!
M3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])
M3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!
M3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLB4$%2
M7R1?(GT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@
M>PHD14Y6>R)005)?)%\B?2`]("1%3E9[(E!!4E]'3$]"04Q?)%\B?2!I9B!E
M>&ES=',@)$5.5GLB4$%27T=,3T)!3%\D7R)].PI]"FEF("@D14Y6>U!!4E]4
M14U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"GT*<W5B(&]U=',@
M>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F
M:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET
M7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE
M9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R
M:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP
M('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005([
M"G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`
M<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R
M:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y=
M"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI
M="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`
M(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI
M="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I
M.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@!P
M97)L>'-I+F,`````0T%#2$4``#X```!!````#````$$````1````00```"<`
M``!!````-@```$$````#````00````8```!!````%0```$$````/````00``
M``X```!!````)@```$$````3````00```"D```!!`````@```$$````9````
M00````H```!!````"P```$$``````````````,B:_W\!``````````0````0
M`````0```$=.50```````P````(`````````!````&P```!^&O[*1D1/`'LB
M='EP92(Z(F1E8B(L(F]S(CHB=6)U;G1U(BPB;F%M92(Z(FQI8G!A<BUP86-K
M97(M<&5R;"(L(G9E<G-I;VXB.B(Q+C`V,RTQ8G5I;&0R(BPB87)C:&ET96-T
M=7)E(CHB87)M:&8B?0````0```!@````?AK^RD9$3P![(G1Y<&4B.B)D96(B
M+")O<R(Z(G5B=6YT=2(L(FYA;64B.B)G;&EB8R(L(G9E<G-I;VXB.B(R+C0Q
M+3%U8G5N='4Q(BPB87)C:&ET96-T=7)E(CHB87)M:&8B?0``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````G1<``%T7```!````-@,```$```!&`P``
M`0```%`#```,````V!$```T```#<.0``&0```+S]`0`;````!````!H```#`
M_0$`'`````0```#U_O]OM`$```4````P"0``!@```*`"```*````RP0```L`
M```0````%0`````````#````S/X!``(```#@`0``%````!$````7````^`\`
M`!$````@#P``$@```-@````3````"````!X````(````^___;P$```C^__]O
MT`X``/___V\"````\/__;_P-``#Z__]O#@``````````````````````````
M``````````````````````````````#$_0$```````````#D$0``Y!$``.01
M``#D$0``Y!$``.01``#D$0``Y!$``.01``#D$0``Y!$``.01``#D$0``Y!$`
M`.01``#D$0``Y!$``.01``#D$0``Y!$``.01``#D$0``Y!$``.01``#D$0``
MY!$``.01``#D$0``Y!$``.01``#D$0``Y!$``.01``#D$0``Y!$``.01``#D
M$0``Y!$``.01``#D$0``Y!$``.01``#D$0``Y!$``.01``#D$0``Y!$``.01
M``#D$0``Y!$``.01``#D$0``Y!$``.01``#D$0``Y!$``.01``#D$0``Y!$`
M`.01````````````````````````````````````````````````````````
M````````````````V10````````$``(`"E!!4BYP;0H`````P#T``-0Z````
M````E#L``)@[``"T/0``W#H``+P]````````H#T``*@]````````R#T``$=#
M0SH@*%5B=6YT=2`Q-"XR+C`M,3=U8G5N='4S*2`Q-"XR+C``03(```!A96%B
M:0`!*`````4W+4$`!@H'00@!"0(*!!($$P$4`14!%P,8`1D!&@(<`2(!`"YS
M:'-T<G1A8@`N;F]T92YG;G4N8G5I;&0M:60`+FEN=&5R<``N9VYU+FAA<V@`
M+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N
M<F5L+F1Y;@`N<F5L+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"Y!
M4DTN97AI9'@`+F5H7V9R86UE`"YN;W1E+D%"22UT86<`+FYO=&4N<&%C:V%G
M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9V]T`"YD871A
M`"YB<W,`+F-O;6UE;G0`+D%232YA='1R:6)U=&5S````````````````````
M```````````````````````````````````+````!P````(```!T`0``=`$`
M`"0```````````````0`````````'@````$````"````F`$``)@!```9````
M```````````!`````````"8```#V__]O`@```+0!``"T`0``[`````0`````
M````!`````0````P````"P````(```"@`@``H`(``)`&```%`````P````0`
M```0````.`````,````"````,`D``#`)``#+!``````````````!````````
M`$````#___]O`@```/P-``#\#0``T@````0``````````@````(```!-````
M_O__;P(```#0#@``T`X``%`````%`````@````0`````````7`````D````"
M````(`\``"`/``#8````!``````````$````"````&4````)````0@```/@/
M``#X#P``X`$```0````6````!`````@```!N`````0````8```#8$0``V!$`
M``P```````````````0`````````:0````$````&````Y!$``.01``#T`@``
M```````````$````!````'0````!````!@```-@4``#8%```!"4`````````
M````"`````````!Z`````0````8```#<.0``W#D```@```````````````0`
M````````@`````$````"````Y#D``.0Y``#X00`````````````$````````
M`(@````!``!P@@```-Q[``#<>P``"`````P`````````!`````````"3````
M`0````(```#D>P``Y'L```0```````````````0`````````G0````<````"
M````Z'L``.A[```@```````````````$`````````*L````'`````@````A\
M```(?```[```````````````!`````````"Y````#@````,```"\_0$`O/T`
M``0```````````````0````$````Q0````\````#````P/T!`,#]```$````
M```````````$````!````-$````&`````P```,3]`0#$_0``"`$```4`````
M````!`````@```#:`````0````,```#,_@$`S/X``#0!``````````````0`
M```$````WP````$````#```````"`````0!(```````````````$````````
M`.4````(`````P```$@``@!(``$`%```````````````!`````````#J````
M`0```#``````````2``!`"8```````````````$````!````\P````,``'``
M`````````&X``0`S```````````````!``````````$````#````````````
:``"A``$``P$``````````````0``````````
